@@ -2,7 +2,7 @@ import json
 import requests
 import logging
 import time
-from antinex_client.log.setup_logging import build_colorized_logger
+from spylunking.log.setup_logging import console_logger
 from antinex_client.utils import ev
 from antinex_client.consts import LOGIN_SUCCESS
 from antinex_client.consts import LOGIN_NOT_ATTEMPTED
@@ -13,7 +13,6 @@ from antinex_client.consts import ERROR
 from antinex_client.consts import NOT_SET
 
 
-name = "ai-client"
 log_level = logging.INFO
 log_level_str = ev(
     "AI_CLIENT_LEVEL",
@@ -29,13 +28,22 @@ elif log_level_str == "critical":
 elif log_level_str == "error":
     log_level = logging.ERROR
 
-log = build_colorized_logger(
-    name=name,
+log = console_logger(
+    name='ai_client',
     log_level=log_level)
 
 
 class AIClient:
 
+    """
+
+    AntiNex Python AI Client
+
+    This can use either environment variables or keyword arguments
+    to create a valid client.
+
+    """
+
     def __init__(
             self,
             user=ev(
@@ -46,7 +54,7 @@ class AIClient:
                 "password-not-set"),
             url=ev(
                 "API_URL",
-                "http://localhost:8080"),
+                "http://localhost:8010"),
             email=ev(
                 "API_EMAIL",
                 "email-not-set"),
@@ -698,7 +706,7 @@ class AIClient:
     def wait_for_job_to_finish(
             self,
             job_id,
-            sec_to_sleep=10.0,
+            sec_to_sleep=5.0,
             max_retries=100000):
         """wait_for_job_to_finish
 
@@ -954,7 +962,7 @@ class AIClient:
     def wait_for_prepare_to_finish(
             self,
             prepare_id,
-            sec_to_sleep=10.0,
+            sec_to_sleep=5.0,
             max_retries=100000):
         """wait_for_prepare_to_finish
 
